@@ -930,7 +930,7 @@ namespace giac {
   void gen_sort_f(iterateur it,iterateur itend,bool (*f)(const gen &a,const gen &b));
   void gen_sort_f_context(iterateur it,iterateur itend,bool (*f)(const gen &a,const gen &b,GIAC_CONTEXT),GIAC_CONTEXT);
   gen makemap(); // make a new map
-  gen chartab2gen(char * & s,GIAC_CONTEXT);
+  gen chartab2gen(char * s,GIAC_CONTEXT);
 
 
   bool is_zero(const gen & a,GIAC_CONTEXT0);
